LoginProgress

Enum LoginProgress 

pub enum LoginProgress {
    Starting,
    EstablishingSecureChannel {
        check_code: CheckCode,
    },
    WaitingForToken {
        user_code: String,
    },
    Done,
}
Available on crate feature e2e-encryption only.
Type telling us about the progress of the QR code login.

Variants



Starting

We’re just starting up, this is the default and initial state.



EstablishingSecureChannel

We have established the secure channel, but we need to let the other side know about the CheckCode so they can verify that the secure channel is indeed secure.

Fields

check_code: CheckCode

The check code we need to, out of band, send to the other device.



WaitingForToken

We’re waiting for the OAuth 2.0 authorization server to give us the access token. This will only happen if the other device allows the OAuth 2.0 authorization server to do so.

Fields

user_code: String

The user code the OAuth 2.0 authorization server has given us, the OAuth 2.0 authorization server might ask the other device to enter this code.



Done

The login process has completed.