pub enum LoginProgress {
Starting,
EstablishingSecureChannel {
check_code: CheckCode,
},
WaitingForToken {
user_code: String,
},
Done,
}Available on crate feature
e2e-encryption only.Expand description
Type telling us about the progress of the QR code login.
Variants
Starting
We’re just starting up, this is the default and initial state.
EstablishingSecureChannel
We have established the secure channel, but we need to let the other
side know about the CheckCode so they can verify that the secure
channel is indeed secure.
WaitingForToken
We’re waiting for the OAuth 2.0 authorization server to give us the access token. This will only happen if the other device allows the OAuth 2.0 authorization server to do so.
Fields
Done
The login process has completed.